/*
 * Copyright (C) 2017 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.tv.settings.system.development;

import android.app.AlertDialog;
import android.app.Dialog;
import android.content.Context;

import androidx.annotation.Nullable;
import androidx.preference.Preference;

import com.android.settingslib.core.lifecycle.Lifecycle;
import com.android.settingslib.development.AbstractLogpersistPreferenceController;
import com.android.tv.settings.R;

/**
 * Preference controller for the Logpersist development preference
 */
public class LogpersistPreferenceController extends AbstractLogpersistPreferenceController {

    private Dialog mLogpersistClearDialog;

    LogpersistPreferenceController(Context context, Lifecycle lifecycle) {
        super(context, lifecycle);
    }

    @Override
    public void showConfirmationDialog(@Nullable Preference preference) {
        // TODO: figure out how to do this with fragments (it's harder than you might think)
        if (preference == null) {
            return;
        }
        if (mLogpersistClearDialog != null) dismissConfirmationDialog();
        mLogpersistClearDialog = new AlertDialog.Builder(mContext)
                .setMessage(R.string.dev_logpersist_clear_warning_message)
                .setTitle(R.string.dev_logpersist_clear_warning_title)
                .setPositiveButton(android.R.string.yes, (dialog, which) -> setLogpersistOff(true))
                .setNegativeButton(android.R.string.no, (dialog, which) -> updateLogpersistValues())
                .show();
        mLogpersistClearDialog.setOnDismissListener(dialog -> mLogpersistClearDialog = null);
    }

    @Override
    public void dismissConfirmationDialog() {
        if (mLogpersistClearDialog != null) {
            mLogpersistClearDialog.dismiss();
            mLogpersistClearDialog = null;
        }
    }

    @Override
    public boolean isConfirmationDialogShowing() {
        return mLogpersistClearDialog != null;
    }
}
